{% extends "justengel_material/base.html" %}
{# extends "base"|with_theme #}

{% block contents %}
<h1>Home</h1>
<p>The home page uses the set theme, and only changes the contents.</p>

<ul>
    <li>Item 1</li>
    <li>Item 2</li>
    <li>Item 3</li>
</ul>

<button class="btn">Button</button>
{% endblock %}
