<span class="chip" style="padding: 1px 10px 1px 1px; height:34px;">
    {% if thumbnail %}<img style="margin: 0; padding: 0 2px 0 0" src="{{ thumbnail }}" alt="">{% else %}{{ account_icon }}{% endif %}
    {% if show_full_name %}{{ user.get_full_name }}{% else %}{{ user.username }}{% endif %}
</span>
