<!doctype html>
<html lang="en">
<head>
  <!--Let browser know website is optimized for mobile-->
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="msqpplication-tap-highlight" content="no">
  <meta name="description" content="Application">

  {% include_block 'head'|with_theme block_name='head' %}

  {% include_block 'extra_head'|with_theme %}

  <title>{% block title %}{% if title %}{{ title }}{% endif %}{% endblock title %}</title>
</head>

<body>
  {% include_block 'begin_body'|with_theme %}

  <header>{% include_block 'navbar'|with_theme %}</header>

  {% include_block 'sidenav'|with_theme %}

  {% include_block 'container'|with_theme %}

  <footer>{% include_block 'footer'|with_theme %}</footer>

  {% block modals %}{% endblock modals %}

  {% include_block 'end_body'|with_theme %}

  {% block scripts %}{% endblock scripts %}
</body>
