name = 'justengel_material'
version = '1.0.5'
description = 'Jinja Materializecss theme capability'
url = 'https://github.com/justengel-web/justengel_material'
author = 'Justin Engel'
author_email = 'jtengel08@gmail.com'
