{% if SHOW_SIDENAV %}
<ul id="nav-sidenav" class="sidenav{% if FIXED_SIDENAV %} sidenav-fixed{% endif %}">
    {% if title %}
<!--    <li class="user_sidenav center"><a class="teal-text" href="/"><img class="circle user_sidenav" src="profile.jpg"></a></li>-->
<!--    <li><h4 class="center"><a class="teal-text" href="/">{{ title }}</a></h4></li>-->
    <li><h4 class="center">{% if MATERIALIZE_SITE_NAME %}{{ MATERIALIZE_SITE_NAME }}{% elif MATERIALIZE_TITLE %}{{ MATERIALIZE_TITLE }}{% else %}{{ site_name }}{% endif %}</h4></li>
    <li><div class="divider"></div></li>
    {% endif %}

    {% include_block 'sidenav_items'|with_theme %}
</ul>
{% endif %}
