{# load justengel_material #}

{% for link in SIDENAV_ITEMS %}
{% if link.links is defined and link.links|length > 0%}
<li class="no-padding">
  <ul class="collapsible collapsible-accordion">
    <li class="active">
      <a class="collapsible-header">{{ link.name }} <i class="material-icons right">arrow_drop_down</i></a>
      <div class="collapsible-body">
        <ul>
        {% for lo in link.links %}
          <li><a href="{{ lo.href }}">{{ lo.name }}</a></li>
        {% endfor %}
        </ul>
      </div>
    </li>
  </ul>
</li>
{% else %}
<li><a href="{{ link.href }}">{{ link.name }}</a></li>
{% endif %}
{% endfor %}
