{# load justengel_material #}
<script type="text/javascript">
{% for message in MESSAGES %}
  M.toast({
    'html': '{{ message.msg }}',
    'classes': '{{ message.msg_class }}',
  });
{% endfor %}
</script>
