<script type="text/javascript">
    // Auto Init materialize javascript components
    M.AutoInit();

    // Turn off the container for small screens
    if(is_small()){
        turn_off_container();
    }

    // check_pickers();
    // check_card_reveal();
    // check_table_of_contents();
</script>
